pydantic
========

|Build Status| |Coverage| |pypi|


Data validation and settings management using python 3.6 type hinting.


TODO:

* performance benchmarks
* make fields truly recursive
* more info: alt names and descriptions
* length limits for lists, dicts etc.
* better info: eg. choices, str length range


.. |Build Status| image:: https://travis-ci.org/samuelcolvin/pydantic.svg?branch=master
   :target: https://travis-ci.org/samuelcolvin/pydantic
.. |Coverage| image:: https://codecov.io/gh/samuelcolvin/pydantic/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/samuelcolvin/pydantic
.. |pypi| image:: https://img.shields.io/pypi/v/pydantic.svg
   :target: https://pypi.python.org/pypi/pydantic
